PythonTorchRuntimeConfig

Struct PythonTorchRuntimeConfig 

pub struct PythonTorchRuntimeConfig {
    pub python_executable: PathBuf,
    pub module_search_roots: Vec<PathBuf>,
    pub workload_factory: String,
    pub workload_config: Value,
    pub env: BTreeMap<String, String>,
}
Configures how the Rust runtime launches the Python worker process.

Fields

python_executable: PathBuf

Python executable used to launch the runtime worker.

module_search_roots: Vec<PathBuf>

Additional module roots appended to PYTHONPATH.

workload_factory: String

Python workload factory in module:attr form.

workload_config: Value

JSON config passed directly to the Python workload.

env: BTreeMap<String, String>

Additional environment variables for the worker process.

Implementations

Source

impl PythonTorchRuntimeConfig

pub fn new( python_executable: impl Into<PathBuf>, workload_factory: impl Into<String>, workload_config: Value, ) -> Self

Creates a new config for the provided Python workload factory.

pub fn with_module_search_root(self, root: impl Into<PathBuf>) -> Self

Adds one extra Python import root.

pub fn with_env(self, key: impl Into<String>, value: impl Into<String>) -> Self

Adds one environment override for the worker process.